@@ -34,7 +34,7 @@ sub new {
     }
 
     my $port;
-    if ( $ssl || $options{ssl} ) {
+    if ( $ssl ) {
         Test::More::note( "ssl mode" );
         $port = $ENV{MQPORT} || 5673;
     }
@@ -513,6 +513,8 @@ sub cleanup {
 
     Test::More::note( "cleaning up" );
 
+    return 1 if !$self->mq->is_connected();
+
     $self->purge( $queue );
     $self->cancel;
     $self->queue_unbind( $queue );
